@@ -498,6 +498,8 @@
 
 				$output .= "ldap.name_filter = (GlobalKeyword=%)\n";
 				$output .= "ldap.number_filter = (GlobalKeyword=%)\n";
+				$output .= "ldap.name_filter = (GlobalTelephoneName=%)\n";
+				$output .= "ldap.number_filter = (GlobalTelephoneNumber=%)\n";
 				$output .= "ldap.host = ".$serveraddr."\n";
 				if ($usestun == 1)
 				{
@@ -808,6 +810,8 @@
 				}
 				//Load bases
 				$output .= LoadW80BMs($ldap, $mac);
+				//Force NAT call audio to go via the DM to avoid NAT issues
+				$output .= "features.media_transmit.enable = 1\n";
 			}
 			if (strcasecmp($model, "SIP-W80BM")==0 && strlen($masterIP)!=0)
 			{
