@@ -345,14 +345,18 @@ $(document).ready(function() {
 	$('body').on('change', '#new_dept select[name=outofhoursdistributiongroup]', function(){
 		selected = $(this).val();
 		timeplan = $( "#timeplan option:selected" ).text();
+		tperror = 0;
 		if (selected.length > 1) {
 			$("#outofhoursmode").val('1');
 			if (timeplan == "Standard") {
 				msg = "For Out Of Hours mode to work a timeplan other than Standard needs to be selected";
+				tperror = 1;
 			} else if (timeplan == '') {
 				msg = "For Out Of Hours mode to work a timeplan needs to be set";
+				tperror = 1;
 			}
-			var n = noty({ type: 'error', layout: 'center', text: 'Please Note:<br/>' + msg + '<br/><br/><i>click to close</i>', dismissQueue: true, theme: 'relax', modal: true, maxVisible:1 });
+			if ( tperror == 1 ) 
+				var n = noty({ type: 'error', layout: 'center', text: 'Please Note:<br/>' + msg + '<br/><br/><i>click to close</i>', dismissQueue: true, theme: 'relax', modal: true, maxVisible:1 });
 		}
 	});
 	
