@@ -178,6 +178,8 @@ if ($actionMode === 'editEndpoint') {
 	
 	$cn = (isset($_REQUEST['phoneName']) && strlen($_REQUEST['phoneName']) >=1 ) ? $_REQUEST['phoneName'] : NULL;
 	$description = (isset($_REQUEST['description']) && strlen($_REQUEST['description']) >=1 ) ? $_REQUEST['description'] : NULL;
+	
+	error_log ("C: $cn S: $selectedName");
 
 	if ($selectedType === '2') {// PCS
 	$serialnumber = (isset($_REQUEST['pcsSerial']) && strlen($_REQUEST['pcsSerial']) >=1 ) ? $_REQUEST['pcsSerial'] : NULL;
@@ -194,6 +196,7 @@ if ($actionMode === 'editEndpoint') {
 	
 	} else if ($selectedType === '3') { // Generic
 	$sipMACAddress = (isset($_REQUEST['sipMACAddress']) && strlen($_REQUEST['sipMACAddress']) >=1 ) ? strtolower($_REQUEST['sipMACAddress']) : NULL;
+	
 	$phoneIPAddress = (isset($_REQUEST['phoneIPAddress']) && strlen($_REQUEST['phoneIPAddress']) >=1 ) ? $_REQUEST['phoneIPAddress'] : NULL;
 	$pnpmodel = (isset($_REQUEST['pnpmodel']) && strlen($_REQUEST['pnpmodel']) >=1 ) ? $_REQUEST['pnpmodel'] : NULL;
 	$pnpvendor = (isset($_REQUEST['pnpvendor']) && strlen($_REQUEST['pnpvendor']) >=1 ) ? $_REQUEST['pnpvendor'] : NULL;
@@ -202,7 +205,7 @@ if ($actionMode === 'editEndpoint') {
 	$stunport = (isset($_REQUEST['stunport']) && strlen($_REQUEST['stunport']) >=1 ) ? $_REQUEST['stunport'] : NULL;
 	$siplicense = (isset($_REQUEST['siplicense']) && $_REQUEST['siplicense'] === '1' ) ? $_REQUEST['siplicense'] : NULL;
 	
-	$att['serialNumber'] = $sipMACAddress;
+	$att['serialnumber'] = $sipMACAddress;
 	$att['ipaddress'] = $phoneIPAddress;
 	$att['pnpmodel'] = $pnpmodel;
 	$att['pnpvendor'] = $pnpvendor;
@@ -236,8 +239,8 @@ if ($actionMode === 'editEndpoint') {
 	
 	$user = '';
 	
-	$name = ($sipType === 'Yealink') ? "SIP $cn" : $selectedName;
-	if ($name != $cn)
+	$name = ($sipType === 'Yealink') ? "SIP $cn" : $cn;
+	if ($selectedName != $cn)
 		ldap_rename($ds,"cn=$selectedName,cn=$selectedSystemName, cn=modules","cn=$name","cn=modules",true);
 	
 	$dontvalidateipaddress = $publicipaddress = '';
@@ -288,7 +291,12 @@ if ($actionMode === 'restartModule') {
 	
 	$ent["dobackup"] = "1";  	
 	ldap_modify($ds,"cn=Commands",$ent);
-  
+	
+	$msg = "Module Restarted by AdminPortal on ". date(DATE_RFC2822);
+	$cmd = "echo  $msg >> /SpliceCom/WebManager/warnings.txt";
+    exec ($cmd, $res);
+    ldap_close ($ds);
+
 	$cmd = "echo $password | sudo -S systemctl restart adminmodule && echo $password | sudo -S systemctl restart compressor && echo $password | sudo -S systemctl restart voicemail";
 	system($cmd,$rv);
 	echo $rv;
