@@ -403,10 +403,14 @@ $(document).ready(function() {
 		var thisVal = $(this).val();
 		var type = $('#sipType').val();
 		var regex = /^([0-9A-Fa-f]{2}){6}$/;
+		
+		if ( type === 'Yealink' ) type = '1'
 
-		if (type === '1')
-			$('#sipName').val($(this).val().toLowerCase())
-
+		if ( type === '1' ) {
+			cleanmac = thisVal.replace(/[^0-9a-fA-F]/g, '');
+			$('#sipMACAddress, #sipName').val( cleanmac.toLowerCase() )
+		}
+		
 		$.ajax({ type: "GET",   
          url: "../assets/inc/names.php?deviceName=" + encodeURIComponent(thisVal),   
          async: true,
