@@ -108,7 +108,7 @@ $system = (isset($_REQUEST['system']) && strlen($_REQUEST['system']) > 1) ? $_RE
 	<tbody>
 	
 <?php  
-$typesofphone = array('1'=>'Splicecom Analogue Port','2'=>'Splicecom PCS IP Phone','3'=>'SIP Phone');
+$typesofphone = array('1'=>'Splicecom Analogue Port','2'=>'Splicecom PCS IP Phone','3'=>'SIP Phone','4'=>'iPCS');
 $sr = ldap_search($ds,"guid=$system, cn=modules","objectclass=Phone",array('cn','description','guid','typeofphone'));
 $info = ldap_get_entries($ds, $sr);
 for ($m=0; $m<$info['count']; $m++) {
