@@ -64,7 +64,27 @@ if ($selectedType === '2'){
 						<span class='information'>PHONE DESCRIPTION</span>
 					</div>
 					
-			<!-- commonValues -->
+				<?php if ($sipType == 'Yealink') {
+					echo "<div class='field'>
+						<label class='grey' for='sipMACAddress'>Yealink Device MAC Address</label>
+						<input type='text' id='sipMACAddress' name='sipMACAddress' value='$sipMACAddress' maxlength='12'>
+						<span class='information'>YEALINK DEVICE MAC ADDRESS</span>
+					</div>";
+					}
+					?>
+
+				<!-- commonValues -->
+
+				<!-- pcsPhone -->
+				<?php if ($selectedType === '2') { ?>
+					<div class='field'>
+						<label class='grey' for="pcsSerial">Phone Serial Number</label>
+						<input type='text' id='pcsSerial' name='pcsSerial' value='<?php echo $pcsSerial ?>' >
+						<span class='information'>SPLICECOM PCS IP SERIAL NUMBER</span>
+					</div>
+				<?php } ?>
+				<!-- pcsPhone -->
+				
 
 				<!-- potsPhone -->
 				<?php if ($selectedType === '1') { ?>
