@@ -19,6 +19,12 @@
 </head>
 <body>
 <?php
+
+// PJC 13-JUL-2020 - Set Encryption Port to 5061 (SIP) 5062 (Teams)
+// PJC 13-JUL-2020 - Update SIP Wizard to SIP / Team Wizard
+// PJC 29JUN2020 added Teams & Encryption Support
+// PJC 29JUN2020 Updated tIPicall to TalkTalk Notice
+// PJC 13-JUL-2020 - Update SIP Wizard to SIP / Team Wizard, redirect to Admin Portal
 // PJC 14/08/2019 - NSG Update
 // PJC 17MAY2019 Added DTMF mode (RFC 2833 / SIP INFO). Updated RTP Range to 8899
 $script=$_SERVER['SCRIPT_NAME']; 	$url = $_SERVER['SERVER_ADDR'];
@@ -38,7 +44,9 @@ require('../assets/inc/ldapConnect.php');
 		
 	$statusCheck = is_connected();
 	if ($statusCheck === True) {
-		$wanIP = (@file_get_contents("https://splicepbx.uk/ip.php")) ? @file_get_contents("https://splicepbx.uk/ip.php") : "";
+		//$wanIP = (@file_get_contents("http://splicepbx.uk/ip.php")) ? @file_get_contents("http://splicepbx.uk/ip.php") : "";
+		$wanIP = (@file_get_contents("https://api.ipify.org")) ? @file_get_contents("https://api.ipify.org") : @file_get_contents("http://ipecho.net/plain");
+
 	} else {
 		$wanIP = '';
 	}
@@ -123,21 +131,21 @@ require('../assets/inc/ldapConnect.php');
   			<li><a href="#step-1">
                 <label class="stepNumber">1</label>
                 <span class="stepDesc">
-                   SIP Module<br />
+                   <span id='step1desc'>SIP</span> Module<br />
                    <small>Module Configuration</small>
                 </span>
             </a></li>
   			<li><a href="#step-2">
                 <label class="stepNumber">2</label>
                 <span class="stepDesc">
-                   SIP Trunk<br />
+                   <span id='step2desc'>SIP</span> Trunk<br />
                    <small>Trunk Configuration</small>
                 </span>
             </a></li>
   			<li><a href="#step-3">
                 <label class="stepNumber">3</label>
                 <span class="stepDesc">
-                   SIP Settings<br />
+                   <span id='step3desc'>SIP</span> Settings<br />
                    <small>Trunk Settings</small>
                 </span>                   
              </a></li>
@@ -151,44 +159,54 @@ require('../assets/inc/ldapConnect.php');
   			<li><a href="#step-5">
                 <label class="stepNumber">5</label>
                 <span class="stepDesc">
-                   SIP Overview<br />
-                   <small>SIP Trunk Overview</small>
+                   <span id='step5desc'>SIP</span> Overview<br />
+                   <small><span id='step5small'>SIP</span> Overview</small>
                 </span>                   
             </a></li>
   			</ul>
 
 			<div id="step-1">	
-				<h2 class="StepTitle">SIP Module Configuration</h2><br/>
+				<h2 class="StepTitle"><span id='step1title'>SIP</span> Module Configuration</h2><br/>
 				
 				<div class="colLeft">
+				<?php 
+					$referrer = ( strpos( $_SERVER['HTTP_REFERER'], 'welcome' ) !== false ) ? 'welcome' : '';
+					echo "<input type='hidden' id='referrer' value='$referrer' />";
+				?>
+				
+				<div class='field' title="Select Trunk Type">
+					<label for="sip_type">Trunk Type</label>
+					<select name="module_type" id="module_type" tabindex='1'><option value="3">SIP Trunk</option><option value="4">Teams Trunk</option></select>
+					<span class='information'>SELECT TRUNK TYPE</span>
+				</div>
 				
 				<div class='field' title="New Trunk Module Name">
 					<label for="sip_name">Module / Trunk Name</label>
-					<input type='text' value='TalkTalkSIP' id='sip_name' name='sip_name' maxlength="16" autocomplete="off" tabindex='1'>
-					<span class='information'>SIP TRUNK NAME</span>
+					<input type='text' value='TalkTalkSIP' id='sip_name' name='sip_name' maxlength="16" autocomplete="off" tabindex='2'>
+					<span class='information'>TRUNK NAME</span>
 				</div>
 				
 				<div class='field' title="New Trunk Module Description">
 					<label for="sip_desc">Module / Trunk Description</label>
-					<input type='text' value='TalkTalk SIP Trunk' id='sip_desc' name='sip_desc' maxlength="64" autocomplete="off" tabindex='2'>
-					<span class='information'>SIP TRUNK DESCRIPTION</span>
+					<input type='text' value='TalkTalk SIP Trunk' id='sip_desc' name='sip_desc' maxlength="64" autocomplete="off" tabindex='3'>
+					<span class='information'>TRUNK DESCRIPTION</span>
 				</div>
 				
 				<div class='field' title="Select Trunk Authentication Type. IP Address Authentication Or Username & Password">
 					<label for="sip_type">Authentication Type</label>
-					<select name="sip_type" id="sip_type" tabindex='3'><option value="0"></option><option value="1">Username & Password</option><option value="2" selected="selected">IP Authentication</option></select>
-					<span class='information'>SIP AUTHENTICATION</span>
+					<select name="sip_type" id="sip_type" tabindex='4'><option value="0"></option><option value="1">Username & Password</option><option value="2" selected="selected">IP Authentication</option></select>
+					<span class='information'>AUTHENTICATION METHOD</span>
 				</div>
 				
 				<div class='field' title="Enter SIP Carriers DNS/IP Address">
-					<label for="sip_dnsip">DNS/IP Address</label>
-					<input type='text' value='91.146.112.10' id='sip_dnsip' name='sip_dnsip' maxlength="64" autocomplete="off" tabindex='4'>
-					<span class='information'>SIP DNS / IP ADDRESS</span>
+					<label for="sip_dnsip">DNS / IP Address</label>
+					<input type='text' value='91.146.112.10' id='sip_dnsip' name='sip_dnsip' maxlength="64" autocomplete="off" tabindex='5'>
+					<span class='information'>DNS / IP ADDRESS</span>
 				</div>
 				
 				<div class='field' title="Select System To Register This Trunk To">
 					<label for="sip_cs">SoftPBX</label>
-					<select name="sip_cs" id="sip_cs" tabindex='5'>
+					<select name="sip_cs" id="sip_cs" tabindex='6'>
 					<option value="0"></option>
 					<?php
 					$dn = "cn=Modules";
@@ -201,7 +219,7 @@ require('../assets/inc/ldapConnect.php');
 					}
 					?>
 					</select>
-					<span class='information'>SoftPBX TO REGISTER THIS SIP MODULE TO</span>
+					<span class='information'>SoftPBX TO REGISTER THIS MODULE TO</span>
 				</div>
 				
 				</div>  <!-- left -->
@@ -210,32 +228,32 @@ require('../assets/inc/ldapConnect.php');
 				
 				<div class='field' title="Enter Trunk Capacity">
 					<label for="sip_caps">Capacity</label>
-					<input type='text' value='<?php echo $trunkCaps ?>' id='sip_caps' name='sip_caps' maxlength="3" autocomplete="off" tabindex='6'>
-					<span class='information'>SIP TRUNK CAPACITY</span>
+					<input type='text' value='<?php echo $trunkCaps ?>' id='sip_caps' name='sip_caps' maxlength="3" autocomplete="off" tabindex='7'>
+					<span class='information'>TRUNK CAPACITY</span>
 				</div>
 				
 				<div class='field' title="Enter Trunk Presentation Number">
 					<label for="sip_pres">Trunk Presentation Number</label>
-					<input type='text' value='' id='sip_pres' name='sip_pres' maxlength="16" autocomplete="off" tabindex='7'>
-					<span class='information'>SIP TRUNK PRESENTATION NUMBER</span>
+					<input type='text' value='' id='sip_pres' name='sip_pres' maxlength="16" autocomplete="off" tabindex='8'>
+					<span class='information'> TRUNK PRESENTATION NUMBER</span>
 				</div>
 				
-				<div class='field' title="Enter SIP Carriers Registrar DNS/IP Address (only enabled if using Username & Password Authentication)">
+				<div class='field' title="Enter Carriers Registrar DNS/IP Address (only enabled if using Username & Password Authentication)">
 					<label for="sip_dnsip_user">Registrar DNS/IP Address</label>
-					<input type='text' value='' id='sip_dnsip_user' name='sip_dnsip_user' maxlength="64" autocomplete="off" tabindex='8' readonly>
-					<span class='information'>SIP TRUNK REGISTRAR IP ADDRESS</span>
+					<input type='text' value='' id='sip_dnsip_user' name='sip_dnsip_user' maxlength="64" autocomplete="off" tabindex='9' readonly>
+					<span class='information'>TRUNK REGISTRAR IP ADDRESS</span>
 				</div>
 
-				<div class='field' title="Enter SIP Registration Username (only enabled if using Username & Password Authentication)">
+				<div class='field' title="Enter Registration Username (only enabled if using Username & Password Authentication)">
 					<label for="sip_username">Registration User Name</label>
-					<input type='text' value='' id='sip_username' name='sip_username' maxlength="64" autocomplete="off" tabindex='9' readonly>
-					<span class='information'>SIP TRUNK REGISTRATION USERNAME</span>
+					<input type='text' value='' id='sip_username' name='sip_username' maxlength="64" autocomplete="off" tabindex='10' readonly>
+					<span class='information'>TRUNK REGISTRATION USERNAME</span>
 				</div>
 
-				<div class='field' title="Enter SIP Registration Password (only enabled if using Username & Password Authentication)">
+				<div class='field' title="Enter Registration Password (only enabled if using Username & Password Authentication)">
 					<label for="sip_password">Registration Password</label>
-					<input type='text' value='' id='sip_password' name='sip_password' maxlength="64" autocomplete="off" tabindex='10' readonly>
-					<span class='information'>SIP TRUNK REGISTRATION PASSWORD</span>
+					<input type='text' value='' id='sip_password' name='sip_password' maxlength="64" autocomplete="off" tabindex='11' readonly>
+					<span class='information'>TRUNK REGISTRATION PASSWORD</span>
 				</div>		
 
 				</div> <!-- right -->
@@ -244,23 +262,33 @@ require('../assets/inc/ldapConnect.php');
 
 		
 		  	<div id="step-2">
-				<h2 class="StepTitle">SIP Trunk Configuration</h2><br/>
+				<h2 class="StepTitle"><span id='step2title'>SIP</span> Trunk Configuration</h2><br/>
 				
 				<div class="colLeft">
 				
-				<div class='field' title="Enter SIP Trunks Packet Time">
+								
+				<div class='field' title="Enable Encryption on Trunk. Must be supported by carrier">
+					<label for="sip_encryption">Enable Encryption</label>
+					<select name="sip_encryption" id="sip_encryption" tabindex='13'>
+					<option value="0">Disabled</option>
+					<option value="1">Enabled</option>
+					</select>
+					<span class='information'>ENABLE ENCRYPTION ON THIS TRUNK</span>
+				</div>	
+				
+				<div class='field' title="Enter Trunks Packet Time">
 					<label for="sip_ptime">Packet Time (ptime)</label>
 					<select name="sip_ptime" id="sip_ptime" tabindex='11'><option value="30">30ms</option><option value="20">20ms</option><option value="10">10ms</option></select>
-					<span class='information'>SIP PACKET TIME (PTIME)</span>
+					<span class='information'>PACKET TIME (PTIME)</span>
 				</div>
 				
-				<div class='field' title="Enter SIP Trunk Source Port. Default 5060">
-					<label for="sip_source">SIP Source Port</label>
+				<div class='field' title="Enter Trunk Source Port. Default 5060">
+					<label for="sip_source">Source Port</label>
 					<input type='text' value='5060' id='sip_source' name='sip_source' maxlength="64" autocomplete="off" tabindex='12'>
-					<span class='information'>SIP SOURCE PORT - DEFAULT 5060</span>
+					<span class='information'>SOURCE PORT - DEFAULT 5060</span>
 				</div>				
 				
-				<div class='field' title="Enter SIP Trunk Compression Type. Normally G711(Relay) Unless Compression Licences Have Been Purchased">
+				<div class='field' title="Enter Trunk Compression Type. Normally G711(Relay) Unless Compression Licences Have Been Purchased">
 					<label for="sip_comp">Compression Type</label>
 					<select name="sip_comp" id="sip_comp" tabindex='13'><option value="0">None</option>
 					<?php
@@ -269,22 +297,22 @@ require('../assets/inc/ldapConnect.php');
 					?>
 					
 					<option value="12" selected="selected">G711 (Relay)</option></select>
-					<span class='information'>SIP COMPRESSION TYPE</span>
+					<span class='information'>COMPRESSION TYPE</span>
 				</div>		
 				
-				<div class='field' title="Enter SIP Receive On Port. Default 5060">
+				<div class='field' title="Enter Receive On Port. Default 5060">
 					<label for="sip_rec_port">Receive On Port</label>
 					<input type="text" name="sip_rec_port" id="sip_rec_port" value="5060" maxlength="16" tabindex='14'/>
 					<span class='information'>NAT RECEIVE PORT - DEFAULT 5060</span>
 				</div>
 				
-				<div class='field' title="Select SIP DTMF Mode. RFC 2833 (default) or SIP INFO">
+				<div class='field' title="Select DTMF Mode. RFC 2833 (default) or SIP INFO">
 					<label for="sip_dtmf">DTMF Mode	</label>
 					<select name="sip_dtmf" id="sip_dtmf" tabindex='15'>
 						<option value="0">RFC 2833</option>
 						<option value="1">SIP INFO</option>
 					</select>
-					<span class='information'>SIP DTMF MODE</span>
+					<span class='information'>DTMF MODE</span>
 				</div>	
 
 				</div> <!-- left -->
@@ -312,7 +340,7 @@ require('../assets/inc/ldapConnect.php');
 				</div>
 				
 				<?php if ($productversion > '1.1') { ?>
-
+				<div class='siptrunk'>
 					<div class='field sipDialPlan' title="Enable SIP DNS SRV. Used By BT">
 						<label for="dnssrv">SIP DNS SRV</label>
 						<div class='checkbox'><label for="dnssrv">&nbsp;<div class="switch"><input type="checkbox" name='dnssrv' id='dnssrv' value="1" tabindex='19'/><div class="slider"></div></div></label></div>
@@ -330,6 +358,7 @@ require('../assets/inc/ldapConnect.php');
 						<input type="text" name="sip_regdomain" id="sip_regdomain" value="" maxlength="64" tabindex='21' disabled/>
 						<span class='information'>SIP REGISTRATION DOMAIN</span>
 					</div>
+				</div>
 			  <?php } ?>
 			
 				</div> <!-- right -->
@@ -337,7 +366,7 @@ require('../assets/inc/ldapConnect.php');
 		
 		
   		<div id="step-3">
-            <h2 class="StepTitle">SIP Trunk Settings</h2><br/>
+            <h2 class="StepTitle"><span id='step3title'>SIP</span> Trunk Settings</h2><br/>
 			
 			<div class="colLeft">
 			
@@ -357,25 +386,26 @@ require('../assets/inc/ldapConnect.php');
 			
 			<div class="colRight">
 			
-			The following number matches will be added to the LCRPlan to allow calls to emergency services: <b>999, 911, 112, 101</b><br><br>
-			<div class='field sipDialPlan' title="Don't Add Emergency Service Number Match Entries">
-				<label>Don't Add Emergency Services</label>
-				<div class='checkbox'><label for="sip_noemerg_lcrplan">&nbsp;<div class="switch"><input type="checkbox" name='sip_noemerg_lcrplan' id='sip_noemerg_lcrplan' value="1" /><div class="slider"></div></div></label></div>
-				<span class='information'>DON'T ADD EMERGENCY SERVICE NUMBERS</span>
+			<div class='siptrunk'>
+				The following number matches will be added to the LCRPlan to allow calls to emergency services: <b>999, 911, 112, 101</b><br><br>
+				<div class='field sipDialPlan' title="Don't Add Emergency Service Number Match Entries">
+					<label>Don't Add Emergency Services</label>
+					<div class='checkbox'><label for="sip_noemerg_lcrplan">&nbsp;<div class="switch"><input type="checkbox" name='sip_noemerg_lcrplan' id='sip_noemerg_lcrplan' value="1" /><div class="slider"></div></div></label></div>
+					<span class='information'>DON'T ADD EMERGENCY SERVICE NUMBERS</span>
+				</div>
+				
+				<div class='field' title="Add Additional Emergency Service Number Match Entries">
+					<label>Additional Emergency Entry</label>
+					<input type='text' name='sip_emerg_lcrplan' id='sip_emerg_lcrplan' value='' maxlength='16' tabindex='25' />
+					<span class='information'>ADDITIONAL EMERGENCY SERVICE NUMBER</span>
+				</div>
 			</div>
-			
-			<div class='field' title="Add Additional Emergency Service Number Match Entries">
-				<label>Additional Emergency Entry</label>
-				<input type='text' name='sip_emerg_lcrplan' id='sip_emerg_lcrplan' value='' maxlength='16' tabindex='25' />
-				<span class='information'>ADDITIONAL EMERGENCY SERVICE NUMBER</span>
-			</div>
-						
 		</div> <!-- right -->
 			
 			<div class='colFull'>
-			<br/>Sites firewall will need to be configured to allow access from the SIP Registration DNS/IP Address: <b><span id='summaryDNSIP'></span></b> on Port <b>5060</b> and for UDP RTP Port Range: <b><?php echo $sip_rtp_ports ?></b><br/><br/>
+			<br/>Sites firewall will need to be configured to allow access from the Registration DNS/IP Address: <b><span id='summaryDNSIP'></span></b> on Port <b>5060</b> and for UDP RTP Port Range: <b><?php echo $sip_rtp_ports ?></b><br/><br/>
 
-			Splicecom recommends that the firewall be configured to only allow access to the SelectVoice system from recognised external IP addresses for the ports required. For example, the address of the SIP provider, as stated above and your own IP address for remote access to complete diagnostic and configuration work.<br/><br/>
+			Splicecom recommends that the firewall be configured to only allow access to the SelectVoice system from recognised external IP addresses for the ports required. For example, the address of the Trunk provider, as stated above and your own IP address for remote access to complete diagnostic and configuration work.<br/><br/>
 	
 			Please refer to the Protocols and Ports document for port information. All other access should be blocked to minimise the risk of access from undesirable sources.<br/><br/>
 			</div>
@@ -435,7 +465,7 @@ require('../assets/inc/ldapConnect.php');
 		</div> <!-- left -->
 			
 			<div class="colRight">
-			
+			<div class='siptrunk'>
 			<div class='field' title="Add Default LCRPlan Entry To New LCR Plan For This Trunk">
 					<label for="sip_trunkgrp">Default LCRPlan Entry</label>
 					<select name="sip_lcr_default" id="sip_lcr_default" tabindex='19'><option value="0">No</option><option value="1">Yes</option></select>
@@ -491,7 +521,41 @@ require('../assets/inc/ldapConnect.php');
 				<div>
 					<input type="submit" name="addRow" value="Add Row" id="addRow" disabled="disabled" />
 				</div>
+			</div>
 			
+			<div class='teamstrunk'>
+			
+			<div class='field' title="Assign DialPlan to Trunk">
+				<label>Select DialPlan To Assign To Teams Trunk</label>
+				<select name="teams_dialplan" id="teams_dialplan">
+					<option value="0"></option>
+					<?php
+						$dn = "cn=dialplans";
+						$filter="(objectclass=dialplan)";
+						$sr=ldap_list($ds, $dn, $filter); $info = ldap_get_entries($ds, $sr);
+						for ($m=0; $m<$info['count']; $m++) {
+							$cn = $info[$m]['cn'][0]; $guid = $info[$m]['guid'][0];
+							$selected = ($cn === 'Standard') ? 'selected' : '';
+							echo "<option value='$guid' $selected>$cn</option>";
+							}
+					?>
+					</select>
+				<span class='information'>SELECT DIALPLAN TO ASSIGN TO TEAMS TRUNK</span>
+			</div>
+			
+			<div class='field' title="LCRPlan Number Match Entry for Teams Dialling">
+				<label>Teams LCRPlan Number Match</label>
+				<input type="text" name="teams_lcrplan_numbermatch" id="teams_lcrplan_numbermatch" size="10" maxlength="16" placeholder='33'/>
+				<span class='information'>LCRPLAN NUMBER MATCH FOR USE WITH TEAMS</span>
+			</div>
+			
+			<div class='field' title="LCRPlan Translate To Entry for Teams Dialling">
+				<label>Teams LCRPlan Translate To</label>
+				<input type="text" name="teams_lcrplan_translateto" id="teams_lcrplan_translateto" size="10"maxlength="16" placeholder='+44%r'/>
+				<span class='information'>LCRPLAN TRANSLATE TO FOR USE WITH TEAMS</span>
+			</div>
+			
+			</div>
 		</div> <!-- right -->
 			
         </div>
@@ -499,7 +563,7 @@ require('../assets/inc/ldapConnect.php');
 		<!--  4  -->
   		
 		<div id="step-5">
-            <h2 class="StepTitle">SIP Summary: Overview of New SIP Trunk</h2><br/>
+            <h2 class="StepTitle"><span id='step5title'>SIP</span> Summary: Overview of New Trunk</h2><br/>
 			
 			
 			<h5>SIP Summary</h5>
@@ -522,7 +586,7 @@ require('../assets/inc/ldapConnect.php');
 				</div>
 				
 				<div class='field sipSummary'>
-					<label>DNS/IP Address</label>
+					<label>DNS / IP Address</label>
 					<span class='summary' id='summaryRegDNSIP'></span>
 				</div>
 				
@@ -532,37 +596,49 @@ require('../assets/inc/ldapConnect.php');
 					<span class='summary' id='summaryPresentation'></span>
 				</div>
 				
-				<?php if ($productversion > '1.1') { ?>
-
-					<div class='field sipSummary'>
-						<label>SIP DNS SRV</label>
-						<span class='summary' id='summaryDNSSRV'></span>
-					</div>
+				<div class='siptrunk'>
+				<div class='field sipSummary'>
+					<label>SIP DNS SRV</label>
+					<span class='summary' id='summaryDNSSRV'></span>
+				</div>
 	
-					<div class='field sipSummary sipsmall'>
-						<label>Registration Contact / Domain</label>
-						<span class='summary' id='summaryRegContact'></span>
-						<span class='summary' id='summaryRegDomain'></span>
-					</div>
+				<div class='field sipSummary sipsmall'>
+					<label>Registration Contact / Domain</label>
+					<span class='summary' id='summaryRegContact'></span>
+					<span class='summary' id='summaryRegDomain'></span>
+				</div>
+				</div>
 					
-				<?php } ?>
 				
+				<div class='teamstrunk'>				
+				<div id='showsummaryddiplan' class='field sipSummary teamstrunk'>
+					<label>Teams DDIPlan</label>
+					<span class='summary' id='summaryTeamsDDIPlan'></span>
+				</div>
 				
+				<div class='field sipSummary sipsmall teamslcrplan'>
+					<label>LCRPlan Number Match / Translato To</label>
+					<span class='summary' id='summaryTeamsLCRNumberMatch'></span>
+					<span class='summary' id='summaryTeamsLCRTranslateTo'></span>
+				</div>
+				</div>
+	
 			</div>
 			<div class='colRight'>
+			
+				<div class='field sipSummary'>
+					<label>Encryption</label>
+					<span class='summary' id='summaryEncryption'></span>
+				</div>
 				
 				<div class='field sipSummary'>
 					<label>NAT Server</label>
 					<span class='summary' id='summaryNATServer'></span>
 				</div>
 				
-				<div class='field sipSummary'>
-					<label>NAT Mode</label>
+				<div class='field sipSummary sipsmall'>
+					<label>NAT Mode / Port</label>
 					<span class='summary' id='summaryNATMode'></span>
-				</div>
-				
-				<div class='field sipSummary'>
-					<label>NAT Port</label>
 					<span class='summary' id='summaryNATPort'></span>
 				</div>
 				
@@ -576,7 +652,7 @@ require('../assets/inc/ldapConnect.php');
 					<span class='summary' id='summaryLCRPlan'></span>
 				</div>
 				
-				<div class='field sipSummary'>
+				<div id='showsummarydialplan' class='field sipSummary siptrunk'>
 					<label>Update DialPlan</label>
 					<span class='summary' id='summaryDialPlan'></span>
 				</div>
