@@ -1,4 +1,5 @@
 <?php
+// PJC 28OCT2020 Added Recording to 999. 911 etc entries
 // PJC 29JUN2020 added Teams & Encryption Support
 // PJC 29JUN2020 Updated tIPicall to TalkTalk Notice
 // PJC 17MAY2019 Added DTMF mode (RFC 2833 / SIP INFO). Updated RTP Range to 8899
@@ -174,10 +175,12 @@ foreach ($digits as $k => $v) {
 
 // Add Emergency LCRPlan Entries
 if ( $typeoftrunk == '3' ) {
+	$recordingaction = ($recordingoff === '0') ? '61' : '1';
+	
 	if (!isset($sip_noemerg_lcrplan) || $sip_noemerg_lcrplan == "NULL" ) {
 		$emerg_no = array("999", "911", "112", "101");
 		foreach ($emerg_no as $emergency) {
-			$att=array('objectclass'=>'LCREntry','dialprimary'=>$emergency,'actionprimary'=>'1', 'timeout'=>'1200','trunkgroupprimary'=>$trunk_grp_guid,'timeplan'=>$std_timeplan);
+			$att=array('objectclass'=>'LCREntry','dialprimary'=>$emergency,'actionprimary'=>$recordingaction, 'timeout'=>'1200','trunkgroupprimary'=>$trunk_grp_guid,'timeplan'=>$std_timeplan);
 			ldap_add($ds,"numbermatch=$emergency,cn=$sip_lcrplan,cn=leastcostcallplans",$att);
 		}
 	}
@@ -185,7 +188,7 @@ if ( $typeoftrunk == '3' ) {
 
 	// Add New Emergency LCRPlan Entry
 	if (isset($sip_emerg_lcrplan) && strlen($sip_emerg_lcrplan) >= 1) {
-		$att=array('objectclass'=>'LCREntry','dialprimary'=>$sip_emerg_lcrplan,'actionprimary'=>'1', 'timeout'=>'1200','trunkgroupprimary'=>$trunk_grp_guid,'timeplan'=>$std_timeplan);
+		$att=array('objectclass'=>'LCREntry','dialprimary'=>$sip_emerg_lcrplan,'actionprimary'=>$recordingaction, 'timeout'=>'1200','trunkgroupprimary'=>$trunk_grp_guid,'timeplan'=>$std_timeplan);
 		ldap_add($ds,"numbermatch=$sip_emerg_lcrplan,cn=$sip_lcrplan,cn=leastcostcallplans",$att);
 	}
 }
