@@ -89,7 +89,7 @@ $(document).ready(function() {
 			
 			var arrayData = [startDay, endDay, startTime, endTime]
 			var arrayData = JSON.stringify(arrayData)
-
+			
 			$.ajax({
 				type: "POST", 
 				cache: false,
@@ -108,12 +108,13 @@ $(document).ready(function() {
 	
 	// delete //
 	$("#btn_delete").click(function() {
-		if (typeof selectedGuid != "undefined" && selectedGuid.length > 3)
+		if (typeof selectedGuid != "undefined" && selectedGuid.length > 3) {
+			var timestamp = Math.floor(Date.now() / 1000); 
 		var n = noty({
         type: 'warning', layout: 'center', text: 'Delete TimePlan: <b>' + selectedName + '</b> ?', dismissQueue: true, theme: 'relax', modal: true, maxVisible:1, 
 		buttons     : [
             {addClass: 'btn btn-primary', text: 'OK', onClick: function ($noty) {
-				$.ajax({ url : 'actions.php?actionMode=delete&selectedName=' + encodeURIComponent(selectedName)});
+				$.ajax({ url : 'actions.php?actionMode=delete&selectedName=' + encodeURIComponent(selectedName) + '&timestamp=' + timestamp});
 					oTable.fnDeleteRow( oTable.$('#' + selectedGuid)[0] );
 					selectedGuid = selectedName = '';
                     $noty.close(); 
@@ -124,6 +125,7 @@ $(document).ready(function() {
                 }
             ]
         });	
+		}
 	});
 
 	
@@ -179,9 +181,7 @@ $(document).ready(function() {
 	$("body").on('click', '#save', function(){
 	var saveTimePlan = $('#cn').val();
 	var loadMode = $('#loadMode').val();
-	
-	console.log( $('#datepicker').val() )
-	
+	var timestamp = Math.floor(Date.now() / 1000); 
 	
 	if ($('#startdayofweek').val() != '0' || $('#starttime').val() != '00 : 00' || $('#enddayofweek').val() != '6' || $('#endtime').val() != '23 : 59') {
 		var n = noty({ type: 'warning', layout: 'center', text: 'Time Band Values Have Been Changed And Not Saved', dismissQueue: true, theme: 'relax', modal: true, maxVisible:1 })
@@ -202,6 +202,7 @@ $(document).ready(function() {
 				var alternateplan = $('#alternateplan').val();
 				var data = $('#popup').serializeArray()
 				data.push({name: 'alternateplan', value: alternateplan});
+				data.push({name: 'timestamp', value: timestamp});
 
 				$.ajax({
 					type: "POST", 
@@ -224,7 +225,7 @@ $(document).ready(function() {
 							timeBands: timeBands,
 							dateExceptions: dateExceptions
 						},
-						url: "actions.php?actionMode=entries&selectedGuid=" + encodeURIComponent(guid), 	
+						url: "actions.php?actionMode=entries&selectedGuid=" + encodeURIComponent(guid) + "&timestamp=" + timestamp, 	
 						success: function(data) {
 							console.log (data)
 						}
