@@ -690,6 +690,14 @@ $(document).ready(function() {
 	// Email Address check //
 	$('body').on('keyup', '#new_user input[name=mail]', function(){
 		var email = $('#mail').val();
+		
+		if ( email.length < 1 ) {
+				$('#msg').html(''); 
+				$('#msg_wrap, #mail').removeClass('error');
+				$("#save").prop("disabled",false);
+				return false
+		}
+		
 		var regex = /^([a-zA-Z0-9_.+-])+\@(([a-zA-Z0-9-])+\.)+([a-zA-Z0-9]{2,4})+$/;
 		if (!regex.test(email)) {
 			$('#msg').html('Invalid or Duplicate Entry'); 
