@@ -214,7 +214,8 @@ Search Scripts :
 	<a href='commandline.php#doreboot' class='tooltip' title='/WebManager/doreboot.php - Reboot System'><b>doreboot.php</b> - Reboot System</a>
 	<a href='commandline.php#dosetmaster' class='tooltip' title='Do Ask/Set Master'><b>dosetmaster.php</b> - Do Ask/Set Master</a>
 	<a href='commandline.php#extract' class='tooltip' title='/WebManager/extract.php - Extract Calls From Admin Log Etc'><b>extract.php</b> - Extract Calls From Admin Log Etc</a>
-	<a href='commandline.php#ftpbackup' class='tooltip' title='/WebManager/ftpbackup.php - Create and FTP Upload System Backup Files'><b>ftpbackup.php</b> - Create and FTP Upload System Backup Files</a>", $ma);
+	<a href='commandline.php#ftpbackup' class='tooltip' title='/WebManager/ftpbackup.php - Create and FTP Upload System Backup Files'><b>ftpbackup.php</b> - Create and FTP Upload System Backup Files</a>
+	<a href='commandline.php#sftpbackup' class='tooltip' title='/WebManager/sftpbackup.php - Create and SFTP Upload System Backup Files'><b>sftpbackup.php</b> - Create and SFTP Upload System Backup Files</a>", $ma);
 	
 	if (! file_exists('/SpliceCom/install/assets/vmap')){
 		check("CMD","<a href='commandline.php#patch' class='tooltip' title='/WebManager/patch.php - Automated Software Upgrade, Can Be Run Via CronTab'><b>patch.php</b> - Automated Software Upgrade</a>", $ma);
@@ -449,4 +450,4 @@ check("CMD","</div>
 </li>
 </ul></div></div>
 </body>
-</html>
\ No newline at end of file
+</html>
