@@ -1,14 +1,18 @@
 <?php
-// v 3.51
+// v 3.80
+//PJC 11-JUN-2020 - Add apache2 logs for  Manager User
 //PJC 12-APR-2019 - Added Gatekeeper
 //PJC 06-DEC-2016 - Additional Logs
 //PJC 03-NOV-2014 - S8000 updates
 //PJC 21102014 - reset link
 //PJC 10072013
+
 session_start();
-$page_id = "045";
+$page_id = "044";
 include "/SpliceCom/WebManager/assist/.access.php";
 $reset = "/SpliceCom/Web/download/reset.txt";
+
+$manager_user = ($_SERVER['PHP_AUTH_USER']);
 $script=$_SERVER['SCRIPT_NAME'];
 include "/SpliceCom/WebManager/assist/tzone.php"; // include timezone
 
@@ -23,9 +27,7 @@ if (isset($_REQUEST['clear'])&& $_REQUEST['clear']==1) {
   closedir($handle);
 	}
 }
-$cmd = "cat /proc/version";
-exec($cmd,$a); $a=$a[0];
-$model = (preg_match('~\b(suse|centos)\b~i',$a)) ? "SoftPBX" : "CallServer";
+
 ?>
 <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"
     "http://www.w3.org/TR/html4/strict.dtd">
@@ -94,14 +96,13 @@ popupWindow = window.open(url,winName,settings)
 <img onClick="window.location = '../index.php'" src="../images/home16.gif" alt="home" title="home" border="0">
 </div>
 
-<div style="position:absolute; top:30px; right:8px" ><strong><?php echo $model ?></strong>: 
+<div style="position:absolute; top:30px; right:8px" ><strong>SoftPBX</strong>: 
 <a href="Admin.php" alt="Admin" title="Admin">Admin</a>&nbsp;|&nbsp;
-<?php if ($model=="CallServer") echo "<a href='Gateway.php' alt='Gateway' title='Gateway'>Gateway</a>&nbsp;|&nbsp;"; ?>
 <a href="Voicemail.php" alt="Voicemail" title="Voicemail">Voicemail</a>
-<?php if ($model=="CallServer") echo "&nbsp;|&nbsp;<a href='Phone.php' alt='Phone' title='Phone'>Phone</a>"; ?>
+
 
 <?php
-if ($model=="SoftPBX"){
+
 	if (file_exists('/SpliceCom/logs/vision.log'))
 		echo "<br/><br/><strong>Vision</strong>: <a href='Vision.php' alt='Vision' title='Vision'>Vision</a>";
 	if (file_exists('/SpliceCom/logs/calllog.log'))
@@ -110,7 +111,11 @@ if ($model=="SoftPBX"){
 		echo "&nbsp;|&nbsp;<a href='CallRecording.php' alt='CallRecording' title='CallRecording'>CallRecording</a>";
 	if (file_exists('/SpliceCom/logs/upcs.log'))
 		echo "<br/><br/><strong>SSL-Gateway</strong>: <a href='SSL-Gateway.php' alt='upcs' title='upcs'>SSL-Gateway</a>";
-}
+	
+	if ($manager_user == 'Manager' ) {
+		echo "<br/><br/><strong>Apache2</strong>: <a href='apacheaccess.php' alt='access_log' title='access_log'>Access Log</a>&nbsp;|&nbsp;<a href='apacheerror.php' alt='error_log' title='error_log'>Error Log</a>";
+	}
+
 ?>
 </div>
 
