@@ -1,4 +1,5 @@
 <?php
+// Removed CS5100, PM5315 added P308
 //bobg 21may08 29mar12
 	$page_id = "013";
 	include "assist/.access.php";
@@ -213,35 +214,26 @@ if ($submit){
 }
 // add temp modules
 if (isset($_GET['add'])) {
-   $cn="zczc temp 5100";
-   $sr=@ldap_list($ds,"cn=Modules","(&(objectclass=Module)(cn=$cn))");
-   $info=ldap_get_entries($ds,$sr);
-   if ($info['count']==0) {
-      $att=array('cn'=>$cn, 'description'=> 'temp module - delete at will', 'moduletype'=>11, 'modulestatus'=>1, 'serialnumber'=>'00-07-d9-00-00-00', 'ipaddress'=>'1.1.1.1', 'objectclass'=>'Module');
-      ldap_add($ds,"cn=$cn,cn=Modules",$att);
-      $att=array('cn'=>'1', 'administrationmode'=>2, 'dhcpservermode'=>2, 'objectclass'=> 'AdministrationModule');
-      ldap_add($ds,"cn=1,cn=$cn,cn=Modules",$att);
-   }
-   $cn="zczc temp 5315";
-   $sr=@ldap_list($ds,"cn=Modules","(&(objectclass=Module)(cn=$cn))");
-   $info=ldap_get_entries($ds,$sr);
-   if ($info['count']==0) {
-      $att=array('cn'=>$cn, 'description'=> 'temp module - delete at will', 'moduletype'=>14, 'modulestatus'=>1, 'serialnumber'=>'00-07-d9-00-00-00', 'ipaddress'=>'1.1.1.2', 'objectclass'=>'Module');
-      ldap_add($ds,"cn=$cn,cn=Modules",$att);
-   }
    $cn="zczc temp 5330";
    $sr=@ldap_list($ds,"cn=Modules","(&(objectclass=Module)(cn=$cn))");
    $info=ldap_get_entries($ds,$sr);
    if ($info['count']==0) {
-      $att=array('cn'=>$cn, 'description'=> 'temp module - delete at will', 'moduletype'=>13, 'modulestatus'=>1, 'serialnumber'=>'00-07-d9-00-00-00', 'ipaddress'=>'1.1.1.3', 'objectclass'=>'Module');
+      $att=array('cn'=>$cn, 'description'=> 'temp PM5330 module - delete at will', 'moduletype'=>13, 'modulestatus'=>1, 'serialnumber'=>'00-07-d9-00-00-00', 'ipaddress'=>'1.1.1.1', 'objectclass'=>'Module');
       ldap_add($ds,"cn=$cn,cn=Modules",$att);
    }
+   $cn="zczc temp P308";
+   $sr=@ldap_list($ds,"cn=Modules","(&(objectclass=Module)(cn=$cn))");
+   $info=ldap_get_entries($ds,$sr);
+   if ($info['count']==0) {
+      $att=array('cn'=>$cn, 'description'=> 'temp P308 module - delete at will', 'moduletype'=>22, 'modulestatus'=>1, 'serialnumber'=>'00-07-d9-00-00-00', 'ipaddress'=>'1.1.1.2', 'objectclass'=>'Module');
+      ldap_add($ds,"cn=$cn,cn=Modules",$att);
+   }
+   
 }
 // delete temp modules
 if (isset($_GET['delete'])) {
-   @ldap_delete($ds,"cn=zczc temp 5100,cn=Modules");
-   @ldap_delete($ds,"cn=zczc temp 5315,cn=Modules");
    @ldap_delete($ds,"cn=zczc temp 5330,cn=Modules");
+   @ldap_delete($ds,"cn=zczc temp P308,cn=Modules");
 }
 // build array of nodes
 $sr=@ldap_list($ds,"cn=Modules","objectclass=Module");
@@ -261,9 +253,10 @@ for($n=0; $n<$info['count'];$n++) {
     elseif ($info[$n]['moduletype'][0]==12) { $modules['type'][$n2]="5108"; $modules['potsp'][$n2]=4; $modules['ipp'][$n2]=1; }
     elseif ($info[$n]['moduletype'][0]==13) { $modules['type'][$n2]="5330"; $modules['potsp'][$n2]=30; $modules['ipp'][$n2]=0; }
     elseif ($info[$n]['moduletype'][0]==14) { $modules['type'][$n2]="5315"; $modules['potsp'][$n2]=15;$modules['ipp'][$n2]=0; }
+	elseif ($info[$n]['moduletype'][0]==22) { $modules['type'][$n2]="P308"; $modules['potsp'][$n2]=8;$modules['ipp'][$n2]=0; }
 // updated
-    elseif ($info[$n]['moduletype'][0]==17) { $modules['type'][$n2]="S8000-Linux"; $modules['potsp'][$n2]=0;$modules['ipp'][$n2]=1; }
-	elseif ($info[$n]['moduletype'][0]==18) { $modules['type'][$n2]="S8000-MAC"; $modules['potsp'][$n2]=0;$modules['ipp'][$n2]=1; }
+    elseif ($info[$n]['moduletype'][0]==17) { $modules['type'][$n2]="SoftPBX-Linux"; $modules['potsp'][$n2]=0;$modules['ipp'][$n2]=1; }
+	elseif ($info[$n]['moduletype'][0]==18) { $modules['type'][$n2]="SoftPBX-MAC"; $modules['potsp'][$n2]=0;$modules['ipp'][$n2]=1; }
 	elseif ($info[$n]['moduletype'][0]==19) { $modules['type'][$n2]="NSG"; $modules['potsp'][$n2]=4;$modules['ipp'][$n2]=1; }
 	elseif ($info[$n]['moduletype'][0]==20) { $modules['type'][$n2]="Vision"; $modules['potsp'][$n2]=0;$modules['ipp'][$n2]=0; }
 // updated
@@ -287,8 +280,8 @@ for($n=0; $n<$info['count'];$n++) {
 }
 
 
-print "<p><b>WARNING</b> : Backup your config before using this tool - you are making very significant changes to the configuration using this feature.<br/>
-<p>This page is primarily for moving users between different modules, perhaps because a 4315 is being replaced by a 5330<br/>
+print "<p><b>WARNING</b> : Backup your config before using this tool - you are making very significant changes to the configuration using this feature.<br>
+<p>This page is primarily for moving users between different modules, perhaps because a 4315 is being replaced by a 5330<br><br>
 When users are moved from one module to another the users initial phone is changed to the module they have been moved to. If the module they are being moved from matches their Current Home this will also be changed to be the module they have been moved to.<br/>
 When Pots ports are moved onto a \"Member\" of the system the destination always starts with port01.<br/><br/>
 To use this feature select the tick box in the 'From' column which applies to the module you wish to move users from, then select the tick box in the 'To' column next to the module you wish to move users to.<br/>
